# PyTools-curso

Suportado Versão 3 do python

Aprendendo a criar projetos 

Link para o curso [Python Pro](https://www.python.pro.br)

[![Build Status](https://travis-ci.org/renankemiya/PyTools-curso.svg?branch=master)](https://travis-ci.org/renankemiya/PyTools-curso)
[![Updates](https://pyup.io/repos/github/renankemiya/PyTools-curso/shield.svg)](https://pyup.io/repos/github/renankemiya/PyTools-curso/)
[![Python 3](https://pyup.io/repos/github/renankemiya/PyTools-curso/python-3-shield.svg)](https://pyup.io/repos/github/renankemiya/PyTools-curso/)

Para instalar:
```Console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt

```


Para conferir qualidade do código:

```Console
flake8

```
